@@ -12,9 +12,6 @@
 f = lambda x: any([λ.startswith(γ) for γ in Γ for λ in x.split('\n')])
 
 t = lambda: all([
-  # Expecation == Observation
-  f("f = lambda x:"),
-  f("f = lambda x:\nt = lambda:"),
-  not f("t = lambda:"),
-  not f(""),
+  f("f = lambda x:"), not f("t = lambda:"),
+  f("f = lambda x:\nt = lambda:"), not f(""),
 ])
